.. |name| replace:: machinerry
.. |summary| replace:: CherryPy-based framework for running tasks repeatedly.

|name|
======

|summary|

.. _repository: https://github.com/the-allanc/machinerry/
.. _documentation: https://machinerry.readthedocs.io/en/stable/
.. _pypi: https://pypi.python.org/pypi/machinerry
.. _coveralls: https://coveralls.io/github/the-allanc/machinerry
.. _license: https://github.com/the-allanc/machinerry/master/LICENSE.txt
.. _travis: https://travis-ci.org/the-allanc/machinerry
.. _codeclimate: https://codeclimate.com/github/the-allanc/machinerry

.. |Build Status| image:: https://img.shields.io/travis/the-allanc/machinerry.svg
    :target: travis_
    :alt: Build Status
.. |Coverage| image:: https://img.shields.io/coveralls/the-allanc/machinerry.svg
    :target: coveralls_
    :alt: Coverage
.. |Docs| image:: https://readthedocs.org/projects/machinerry/badge/?version=stable&style=flat
    :target: documentation_
    :alt: Docs
.. |Release Version| image:: https://img.shields.io/pypi/pyversions/machinerry.svg
    :target: pypi_
    :alt: Release Version
.. |Python Version| image:: https://img.shields.io/pypi/v/machinerry.svg
    :target: pypi_
    :alt: Python Version
.. |License| image:: https://img.shields.io/pypi/l/machinerry.svg
    :target: license_
    :alt: License
.. |Code Climate| image:: https://img.shields.io/codeclimate/issues/github/the-allanc/machinerry.svg
    :target: codeclimate_
    :alt: Code Climate

|Docs| |Release Version| |Python Version| |License| |Build Status| |Coverage| |Code Climate|

.. all-content-above-will-be-included-in-sphinx-docs

You can browse the source code and file bug reports at the project repository_. Full documentation can be found `here`__.

__ documentation_
